// @author John Hawksley

// Utils for the JS progressbar.

pbTimer = null;

animStop = false;
ajaxStop = false;

// LOADERS

function loadProgressBar()
{
    $("#progressbar").progressbar({
        value : 0
    });
}

// Read params from hidden fields - vars are global
function readParams()
{
    pingUrl = $('#pingUrl').val();
    onTimeoutUrl = $('#onTimeoutUrl').val();
    onCompleteUrl = $('#onCompleteUrl').val();
    maxWait = $('#maxWait').val() * 1000;
    pingInterval = $('#pingInterval').val() * 1000;
    pingTimeout = $('#pingTimeout').val() * 1000;

    timeoutTime = new Date().getTime() + maxWait;
}

function pbupdater()
{
    currentPct = $("#progressbar").progressbar("value");

    // The first figure in these calculations is the ratio of maxWait we'll
    // spend in each phase.
    // The second figure is the step size, i.e. the number of animation updates
    // done at that phase.
    // This must match the conditions in the if ladder.
    // E.g. We start with the slowest phase (originally 96-100%) -> at 0.33 of
    // maxWait, 5 steps.
    // Next is 81 to 95% at 0.29 of maxWait, 15 steps.
    // Next is 51 to 80% at 0.23 of maxWait, 30 steps.
    // The fastest speed of the bar is 0 to 50% of maxWait, at 0.15 ratio, 50
    // steps.

    nextWait = (maxWait * 0.33) / 5;

    if (currentPct <= 95)
        nextWait = (maxWait * 0.29) / 15;
    if (currentPct <= 80)
        nextWait = (maxWait * 0.23) / 30;
    if (currentPct <= 50)
        nextWait = (maxWait * 0.15) / 50;

    $("#progressbar").progressbar("value", currentPct + 1);

    window.clearInterval(pbTimer);

    if (currentPct < 100 || animStop)
    {
        pbTimer = window.setInterval('pbupdater()', nextWait);
    }
}

// This function checks to see whether a given request is alive or not.
// It self-schedules.
function ajaxPoller()
{
    var now = new Date().getTime();

    // Do ajax check
    result = null;

    $.ajax({
        url : pingUrl,
        async : false,
        timeout : pingTimeout,
        success : function(data)
        {
            result = data;
        }
    });

    // Check result

    // If ok, redir to onCompleteUrl

    if (result.indexOf('finished=yes') != -1)
    {
        animStop = true;
        window.location = onCompleteUrl;
    }

    // Check if we've timed out
    if (now > timeoutTime)
    {
        animStop = true;
        window.location = onTimeoutUrl;
    } else
    {
        // Reschedule ourselves.

        if (!ajaxStop)
        {
            window.setTimeout('ajaxPoller()', pingInterval);
        }
    }
}

// READY FUNC

$(document).ready(function()
{
    // Read out the params
    readParams();

    // Load the status divs
    loadProgressBar();

    // Start the PB animation updater
    pbTimer = window.setInterval('pbupdater()', 50);

    // Do the first poll (ajaxPoller is self-scheduling thereafter)
    window.setTimeout('ajaxPoller()', pingInterval);
});
